(* $Id: menu_profile_list.ml 1001 2012-06-06 21:03:57Z gerd $
 * ----------------------------------------------------------------------
 * Copyright 2012 by Gerd Stolpmann.
 *
 * This file is part of godi-tools.
 *
 * godi-tools is free software; you can redistribute it and/or modify it
 * under the conditions in the file LICENSE.
 *
 * godi-tools is distributed WITHOUT ANY WARRANTY, as detailed in the
 * file LICENSE.
 *)

open Godi_types
open Printf


let help_str =
  "This menu shows the available profiles, and allows you to select\n\
   the profile to use.\n\
   \n\
   A profile controls the sources:\n\
   \n\
    - Which GODI section is active (e.g. 3.12)\n\
    - From where to download packages\n\
   \n\
   Also, a profile allows you to fine-tune the sources:\n\
   \n\
    - Certain package versions can be forced or masked out\n\
    - Package options can be automatically set\n\
    - Patches can be automatically applied (in addition to the patches\n\
    \032 already included in the packages)\n\
   \n\
   A default profile \"head_<section>\" is installed when GODI is\n\
   bootstrapped, defaulting to getting the latest packages for the\n\
   selected GODI section. You can install additional profiles from\n\
   the command-line. See the GODI manual for details.\n\
   \n\
   After switching profiles, you need to update the list of packages."


let display (pg : Miniui.page) =

  let rec show() =
    pg # clear();

    Menu_aux.add_compact_head ~lmargin:6 pg ">>> Profiles <<<";

    pg # put_line "";
    
    let l = Godi_profile_ops.commented_list() in
    let p = Godi_profile_ops.current() in
    let la = Array.of_list l in
    let la' =
      Array.mapi
        (fun k (name, comment) ->
           `Item( [ sprintf "[%2d]" (k+1);
                    (if name = p. Godi_profile.prof_name then "*" else " ");
                    name;
                    comment
                  ],
                  (k+1),
                  (fun () ->
                     Godi_profile_ops.enable name;
                     show()
                  )
                )
        )
        la in
    Menu_aux.add_menu
      pg
      [ `Left 4; `Delim " "; `Left 1; `Delim " "; 
        `Left 20; `Delim " "; `Left 50 ]
      (Array.to_list la');

    ignore(pg # add_foot_button ~text:"help" ~underline:0
             ~callback:(Menu_help.display pg#new_page help_str)
             (`Keypress 'h'));
    
    ignore(pg # add_foot_button ~text:"exit menu" ~underline:1
             ~callback:pg#quit (`Keypress 'x'));
  in
  
  try
    show();
    pg # loop()
  with
    | User_error msg ->
        Menu_aux.error_page pg msg
;;
